Crate doip_rw_tokio

Crate doip_rw_tokio 

DoIP tokio messaging library

This library offers an API to connect, receive connection, send and receive DoIP messages, both on UDP and TCP.

It enables async operations thanks to tokio framework.

An example is provided in the examples directory, implementing a very simple DoIP entity accepting connections, and replying to DoIP requests.

The API is thread agnostics and memory allocation agnostic. When a buffer is required, the API will require an allocator from the caller. This way, the caller might have a ring buffer, and reuse buffers, preventing any memory allocation.

The first usage of the API should always be either :

Structs

DoIpTcpConnection
DoIpTcpConnection
DoIpUdpConnection
DoIpUdpConnection
Timings
Timings

Enums

DoIpCnxError
A DoIP API error
DoIpTcpMessage
DoIpMessage on TCP stream.
DoIpUdpMessage
DoIpMessage on UDP stream.

Functions

accept_doip_tcp
Accept a connection from a client for a DoIP over TCP connection.
connect_doip_tcp
Create a client DoIP over TCP connection.
create_doip_udp
Create a client DoIP over UDP local endpoint.
receive_uds
Receive an UDS diagnostic message.
send_uds
Send an UDS diagnostic message.