DoIP tokio messaging library
This library offers an API to connect, receive connection, send and receive DoIP messages, both on UDP and TCP.
It enables async operations thanks to tokio framework.
An example is provided in the examples directory, implementing a very simple DoIP entity accepting connections, and replying to DoIP requests.
The API is thread agnostics and memory allocation agnostic. When a buffer is required, the API will require an allocator from the caller. This way, the caller might have a ring buffer, and reuse buffers, preventing any memory allocation.
The first usage of the API should always be either :
connect_doip_tcp()for the TCP DoIP stream for an external tester.accept_doip_tcp()for the TCP DoIP stream for a DoIP entity.create_doip_udp()for the UDP DoIP stream.
Structs
- DoIp
TcpConnection - DoIpTcpConnection
- DoIp
UdpConnection - DoIpUdpConnection
- Timings
- Timings
Enums
- DoIp
CnxError - A DoIP API error
- DoIp
TcpMessage - DoIpMessage on TCP stream.
- DoIp
UdpMessage - DoIpMessage on UDP stream.
Functions
- accept_
doip_ tcp - Accept a connection from a client for a DoIP over TCP connection.
- connect_
doip_ tcp - Create a client DoIP over TCP connection.
- create_
doip_ udp - Create a client DoIP over UDP local endpoint.
- receive_
uds - Receive an UDS diagnostic message.
- send_
uds - Send an UDS diagnostic message.